@@ -28,8 +28,8 @@ class InterruptEvent(Event):
 
 
 class TimeoutEvent(Event):
-    def __init__(self):
-        super().__init__("timeout")
+    def __init__(self, count: int = 0, ms_since_input: int = 0):
+        super().__init__("timeout", {"count": count, "ms_since_input": ms_since_input})
 
 
 class TextEvent(Event):
@@ -38,16 +38,26 @@ class TextEvent(Event):
 
 
 class TextToSpeechEvent(Event):
-    def __init__(self, text: str, voice="nova", cache=True, interruptable=True, instructions="", speed=1.0):
+    def __init__(
+        self,
+        text: str,
+        voice="nova",
+        cache=True,
+        interruptible: bool = True,
+        instructions="",
+        speed=1.0,
+        stream=False,
+    ):
         super().__init__(
             "text_to_speech",
             {
                 "text": text,
                 "voice": voice,
                 "cache": cache,
-                "interruptable": interruptable,
+                "interruptible": interruptible,
                 "instructions": instructions,
                 "speed": speed,
+                "stream": stream,
             },
         )
 
@@ -140,7 +150,9 @@ class StopRecordingEvent(Event):
 
 
 class STTUpdateSettingsEvent(Event):
-    def __init__(self, language: str = None, prompt: str = None, endpointing: int = None):
+    def __init__(
+        self, language: str = None, prompt: str = None, endpointing: int = None
+    ):
         super().__init__(
             "stt_update_settings",
             {
@@ -151,6 +163,16 @@ class STTUpdateSettingsEvent(Event):
         )
 
 
+class TurnEndEvent(Event):
+    def __init__(self, duration: int):
+        super().__init__("turn_end", {"duration": duration})
+
+
+class TurnInterruptedEvent(Event):
+    def __init__(self):
+        super().__init__("turn_interrupted", {})
+
+
 def event_to_str(event: Event) -> str:
     return json.dumps({"name": event.name, "data": event.data})
 
@@ -171,15 +193,16 @@ def event_from_str(event_str: str) -> Event:
         "start": StartEvent,
         "stop": StopEvent,
         "text_to_speech": lambda: TextToSpeechEvent(
-            data["text"], 
+            data["text"],
             data.get("voice", "nova"),
             data.get("cache", True),
-            data.get("interruptable", True),
+            data.get("interruptible", True),
             data.get("instructions", ""),
-            data.get("speed", 1.0)
+            data.get("speed", 1.0),
+            data.get("stream", False),
         ),
         "text": lambda: TextEvent(data["source"], data["text"]),
-        "timeout": TimeoutEvent,
+        "timeout": lambda: TimeoutEvent(data["count"], data["ms_since_input"]),
         "transfer_call": lambda: TransferCallEvent(data["phone_number"]),
         "warm_transfer": lambda: WarmTransferEvent(data["phone_number"], data["data"]),
         "collect_payment": lambda: CollectPaymentEvent(data["amount"]),
@@ -191,6 +214,11 @@ def event_from_str(event_str: str) -> Event:
         "update_call": lambda: UpdateCallEvent(data["data"]),
         "start_recording": lambda: StartRecordingEvent(data["status_callback_url"]),
         "stop_recording": StopRecordingEvent,
+        "stt_update_settings": lambda: STTUpdateSettingsEvent(
+            data.get("language"), data.get("prompt"), data.get("endpointing")
+        ),
+        "turn_end": lambda: TurnEndEvent(data["duration"]),
+        "turn_interrupted": TurnInterruptedEvent,
     }
 
     if name in event_types:
